@@ -1,7 +1,5 @@
 package Tangerine::hook::prefixedlist;
-{
-  $Tangerine::hook::prefixedlist::VERSION = '0.11';
-}
+$Tangerine::hook::prefixedlist::VERSION = '0.12';
 use 5.010;
 use strict;
 use warnings;
@@ -27,7 +25,8 @@ sub run {
             @args = @args[($voffset) .. $#args];
             @args = stripquotelike(@args);
         }
-        @args = $args[0] if $s->[1] eq 'Inline';
+        @args = $args[0] ? ($args[0]) : ()
+            if $s->[1] eq 'Inline';
         return Tangerine::HookData->new(
             modules => {
                 map {
@@ -65,7 +64,7 @@ Petr Šabata <contyk@redhat.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014 Petr Šabata
+Copyright (c) 2014-2015 Petr Šabata
 
 See LICENSE for licensing details.
 
