@@ -1,7 +1,5 @@
 package Tangerine::hook::tests;
-{
-  $Tangerine::hook::tests::VERSION = '0.11';
-}
+$Tangerine::hook::tests::VERSION = '0.12';
 use 5.010;
 use strict;
 use warnings;
@@ -21,6 +19,12 @@ sub run {
         return Tangerine::HookData->new( hooks => [
                 Tangerine::hook::testloading->new(type => 'req') ] );
     }
+    if ((any { $s->[0] eq $_ } qw(use no)) && scalar(@$s) > 1 &&
+        $s->[1] eq 'Test::Requires') {
+        require Tangerine::hook::testrequires;
+        return Tangerine::HookData->new( hooks => [
+                Tangerine::hook::testrequires->new(type => 'req') ] );
+    }
     return;
 }
 
@@ -54,7 +58,7 @@ Petr Šabata <contyk@redhat.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014 Petr Šabata
+Copyright (c) 2014-2015 Petr Šabata
 
 See LICENSE for licensing details.
 
