@@ -1,7 +1,5 @@
 package Tangerine::hook::xxx;
-{
-  $Tangerine::hook::xxx::VERSION = '0.11';
-}
+$Tangerine::hook::xxx::VERSION = '0.12';
 use 5.010;
 use strict;
 use warnings;
@@ -15,7 +13,6 @@ extends 'Tangerine::Hook';
 
 sub run {
     my ($self, $s) = @_;
-    my $defaultbackend = 'YAML';
     if ((any { $s->[0] eq $_ } qw(use no)) &&
         scalar(@$s) > 2 && $s->[1] eq 'XXX' && $self->type eq 'use') {
         my $module;
@@ -26,13 +23,10 @@ sub run {
         } elsif ($s->[2] eq '-with' && $s->[4]) {
             $module = stripquotelike($s->[4]);
         }
-        $module //= $defaultbackend;
         return Tangerine::HookData->new( modules => {
-                $module => Tangerine::Occurence->new } );
-    } elsif ($s->[0] eq 'require' && $s->[1] eq 'XXX' && $self->type eq 'req') {
-        return Tangerine::HookData->new( modules => {
-                $defaultbackend => Tangerine::Occurence->new } );
-    }
+                $module => Tangerine::Occurence->new } )
+            if $module;
+        }
     return;
 }
 
@@ -63,7 +57,7 @@ Petr Šabata <contyk@redhat.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014 Petr Šabata
+Copyright (c) 2014-2015 Petr Šabata
 
 See LICENSE for licensing details.
 
